@@ -1,8 +1,11 @@
 __copyright__ = "Copyright (c) 2020 Jina AI Limited. All rights reserved."
 __license__ = "Apache-2.0"
 
+if False:
+    from argparse import Namespace
 
-def pod(args):
+
+def pod(args: 'Namespace'):
     """Start a Pod"""
     from jina.peapods import Pod
     try:
@@ -12,7 +15,7 @@ def pod(args):
         pass
 
 
-def pea(args):
+def pea(args: 'Namespace'):
     """Start a Pea"""
     from jina.peapods import Pea
     try:
@@ -22,35 +25,35 @@ def pea(args):
         pass
 
 
-def gateway(args):
+def gateway(args: 'Namespace'):
     """Start a Gateway Pod"""
     pod(args)
 
 
-def log(args):
+def log(args: 'Namespace'):
     """Receive piped log output and beautify the log"""
     from jina.logging.pipe import PipeLogger
     PipeLogger(args).start()
 
 
-def check(args):
+def check(args: 'Namespace'):
     """Check jina config, settings, imports, network etc"""
     from jina.checker import ImportChecker
     ImportChecker(args)
 
 
-def ping(args):
+def ping(args: 'Namespace'):
     from jina.checker import NetworkChecker
     NetworkChecker(args)
 
 
-def client(args):
+def client(args: 'Namespace'):
     """Start a client connects to the gateway"""
     from jina.clients import Client
     Client(args)
 
 
-def export_api(args):
+def export_api(args: 'Namespace'):
     from .export import api_to_dict
     from jina import __version__
     from jina.logging import default_logger
@@ -72,12 +75,12 @@ def export_api(args):
             default_logger.info(f'API is exported to {f_name}')
 
 
-def hello_world(args):
+def hello_world(args: 'Namespace'):
     from jina.helloworld import hello_world
     hello_world(args)
 
 
-def flow(args):
+def flow(args: 'Namespace'):
     """Start a Flow from a YAML file or a docker image"""
     from jina.flow import Flow
     if args.uses:
@@ -88,8 +91,13 @@ def flow(args):
         from jina.logging import default_logger
         default_logger.critical('start a flow from CLI requires a valid "--uses"')
 
+def optimizer(args: 'Namespace'):
+    """Start an optimization from a YAML file"""
+    from jina.optimizers import run_optimizer_cli
+    run_optimizer_cli(args)
 
-def hub(args):
+
+def hub(args: 'Namespace'):
     """Start a hub builder for build, push, pull"""
     from jina.docker.hubio import HubIO
     getattr(HubIO(args), args.hub)()
