@@ -57,9 +57,12 @@ async def _clear_all():
     summary='Terminate a running Pod',
     description='Terminate a running Pod and release its resources'
 )
-async def _delete(id: uuid.UUID):
+async def _delete(
+        id: uuid.UUID,
+        workspace: bool = False
+):
     try:
-        del store[id]
+        store.delete(id=id, workspace=workspace)
     except KeyError:
         raise HTTPException(status_code=404, detail=f'{id} not found in {store!r}')
 
