@@ -42,8 +42,6 @@ class BaseEvaluateDriver(BaseExecutableDriver):
     def _apply_all(
             self,
             docs: Iterator['DocGroundtruthPair'],
-            context_doc: 'DocGroundtruthPair' = None,
-            field: str = None,
             *args,
             **kwargs
     ) -> None:
@@ -55,7 +53,7 @@ class BaseEvaluateDriver(BaseExecutableDriver):
             if self._running_avg:
                 evaluation.value = self.exec.mean
 
-            if hasattr(self.exec, 'eval_at'):
+            if getattr(self.exec, 'eval_at', None):
                 evaluation.op_name = f'{self.exec.__class__.__name__}@{self.exec.eval_at}'
             else:
                 evaluation.op_name = self.exec.__class__.__name__
