@@ -1,5 +1,4 @@
-import uuid
-from typing import Union, List, Iterator, Dict
+from typing import Union, List, Iterator
 
 import numpy as np
 
@@ -156,7 +155,7 @@ class Flow(BaseFlow):
                                                  **kwargs)
 
     @deprecated_alias(buffer=('input_fn', 1), callback=('on_done', 1), output_fn=('on_done', 1))
-    def search_lines(self, filepath: str = None, lines: Iterator[str] = None, size: int = None,
+    def search_lines(self, lines: Iterator[str] = None, filepath: str = None, size: int = None,
                      sampling_rate: float = None, read_mode='r',
                      on_done: CallbackFnType = None,
                      on_error: CallbackFnType = None,
