@@ -35,16 +35,6 @@ class IntegerParameter(OptimizationParameter):
         # The step != 1 and log arguments cannot be used at the same time.
         # To set the log argument to True, set the step argument to 1.
         self.log = log
-        self.optuna_method = 'suggest_int'
-
-    def to_optuna_args(self):
-        return {
-            'name': self.jaml_variable,
-            'low': self.low,
-            'high': self.high,
-            'step': self.step_size,
-            'log': self.log,
-        }
 
 
 class FloatParameter(OptimizationParameter):
@@ -62,16 +52,6 @@ class FloatParameter(OptimizationParameter):
         self.high = high
         self.step_size = step_size
         self.log = log
-        self.optuna_method = 'suggest_float'
-
-    def to_optuna_args(self):
-        return {
-            'name': self.jaml_variable,
-            'low': self.low,
-            'high': self.high,
-            'step': self.step_size,
-            'log': self.log,
-        }
 
 
 class UniformParameter(OptimizationParameter):
@@ -79,14 +59,6 @@ class UniformParameter(OptimizationParameter):
         super().__init__(*args, **kwargs)
         self.low = low
         self.high = high
-        self.optuna_method = 'suggest_uniform'
-
-    def to_optuna_args(self):
-        return {
-            'name': self.jaml_variable,
-            'low': self.low,
-            'high': self.high,
-        }
 
 
 class LogUniformParameter(OptimizationParameter):
@@ -94,14 +66,6 @@ class LogUniformParameter(OptimizationParameter):
         super().__init__(*args, **kwargs)
         self.low = low
         self.high = high
-        self.optuna_method = 'suggest_loguniform'
-
-    def to_optuna_args(self):
-        return {
-            'name': self.jaml_variable,
-            'low': self.low,
-            'high': self.high,
-        }
 
 
 class CategoricalParameter(OptimizationParameter):
@@ -110,10 +74,6 @@ class CategoricalParameter(OptimizationParameter):
     ):
         super().__init__(*args, **kwargs)
         self.choices = choices
-        self.optuna_method = 'suggest_categorical'
-
-    def to_optuna_args(self):
-        return {'name': self.jaml_variable, 'choices': self.choices}
 
 
 class DiscreteUniformParameter(OptimizationParameter):
@@ -122,15 +82,6 @@ class DiscreteUniformParameter(OptimizationParameter):
         self.low = low
         self.high = high
         self.q = q
-        self.optuna_method = 'suggest_discrete_uniform'
-
-    def to_optuna_args(self):
-        return {
-            'name': self.jaml_variable,
-            'low': self.low,
-            'high': self.high,
-            'q': self.q,
-        }
 
 
 def load_optimization_parameters(filepath: str):
