@@ -1,3 +1,4 @@
+from jina.helper import random_identity
 from jina.parsers.helper import add_arg_group
 
 
@@ -13,15 +14,15 @@ def mixin_distributed_feature_parser(parser):
 The files on the host to be uploaded to the remote
 workspace. This can be useful when your Pod has more
 file dependencies beyond a single YAML file, e.g.
-Python files, data files. 
+Python files, data files.
 
-Note, 
-- currently only flatten structure is supported, which means if you upload `[./foo/a.py, ./foo/b.pp, ./bar/c.yml]`, then they will be put under the _same_ workspace on the remote, losing all hierarchies. 
-- by default, `--uses` YAML file is always uploaded. 
+Note,
+- currently only flatten structure is supported, which means if you upload `[./foo/a.py, ./foo/b.pp, ./bar/c.yml]`, then they will be put under the _same_ workspace on the remote, losing all hierarchies.
+- by default, `--uses` YAML file is always uploaded.
 - uploaded files are by default isolated across the runs. To ensure files are submitted to the same workspace across different runs, use `--workspace-id` to specify the workspace.
 ''')
 
-    gp.add_argument('--workspace-id', type=str,
-                    help='The UUID for identifying the workspace on remote. When not given then remote will assign a '
-                         'random one. Multiple Pea/Pod/Flow will work under the same workspace if they share the same '
+    gp.add_argument('--workspace-id', type=str, default=random_identity(),
+                    help='the UUID for identifying the workspace. When not given a random id will be assigned.'
+                         'Multiple Pea/Pod/Flow will work under the same workspace if they share the same '
                          '`workspace-id`.')
