@@ -4,7 +4,7 @@ from typing import Type
 
 from .helper import _get_event, _make_or_event, PeaType
 from ... import __stop_msg__, __ready_msg__, __default_host__
-from ...enums import PeaRoleType, RuntimeBackendType, RemoteAccessType
+from ...enums import PeaRoleType, RuntimeBackendType
 from ...excepts import RuntimeFailToStart, RuntimeTerminated
 from ...helper import typename
 from ...logging.logger import JinaLogger
@@ -34,12 +34,10 @@ class BasePea(metaclass=PeaType):
         self.is_ready = _get_event(self)
         self.is_shutdown = _get_event(self)
         self.ready_or_shutdown = _make_or_event(self, self.is_ready, self.is_shutdown)
-        self.logger = JinaLogger(self.name,
-                                 log_id=self.args.log_id,
-                                 log_config=self.args.log_config)
+        self.logger = JinaLogger(self.name, **vars(self.args))
 
         self._envs = {'JINA_POD_NAME': self.name,
-                      'JINA_LOG_ID': self.args.log_id}
+                      'JINA_LOG_ID': self.args.identity}
         if self.args.env:
             self._envs.update(self.args.env)
 
@@ -63,6 +61,7 @@ class BasePea(metaclass=PeaType):
         """
         self._set_envs()
 
+        self.logger.info(f'starting {typename(self.runtime)}...')
         try:
             self.runtime.setup()
         except Exception as ex:
@@ -181,11 +180,7 @@ class BasePea(metaclass=PeaType):
         v = self.runtime_cls
         if not self.runtime_cls:
             if self.args.host != __default_host__:
-                if self.args.remote_access == RemoteAccessType.JINAD:
-                    self.args.runtime_cls = 'JinadRuntime'
-                elif self.args.remote_access == RemoteAccessType.SSH:
-                    self.args.runtime_cls = 'SSHRuntime'
-
+                self.args.runtime_cls = 'JinadRuntime'
             if self.args.runtime_cls == 'ZEDRuntime' and self.args.uses.startswith('docker://'):
                 self.args.runtime_cls = 'ContainerRuntime'
 
