@@ -58,7 +58,6 @@ class JinadRuntime(AsyncZMQRuntime):
     @cached_property
     def _remote_id(self) -> Optional[str]:
         if self.api.is_alive:
-            workspace_id = None
             upload_files = []
             if self.args.uses.endswith('.yml') or self.args.uses.endswith('.yaml'):
                 upload_files.append(self.args.uses)
@@ -69,14 +68,13 @@ class JinadRuntime(AsyncZMQRuntime):
                 upload_files.extend(self.args.upload_files)
 
             if upload_files:
-                workspace_id = self.api.upload(list(set(upload_files)))
+                workspace_id = self.api.upload(dependencies=list(set(upload_files)),
+                                               workspace_id=self.args.workspace_id)
                 if workspace_id:
-                    self.logger.success(f'uploaded to workspace: {workspace_id}')
+                    self.logger.success(f'uploaded to workspace: {colored(workspace_id, "cyan")}')
                 else:
                     raise RuntimeError('can not upload required files to remote')
 
-            # if there is a workspace_id (upload is called), then use it
-            self.args.workspace_id = workspace_id
             _id = self.api.create(self.args)
 
             # if there is a new workspace_id, then use it
