@@ -3,7 +3,13 @@ from typing import Callable
 from typing import Union, Sequence, Iterable, Tuple
 
 import numpy as np
-from google.protobuf.pyext._message import RepeatedCompositeContainer
+
+try:
+    # when protobuf using Cpp backend
+    from google.protobuf.pyext._message import RepeatedCompositeContainer as RepeatedContainer
+except:
+    # when protobuf using Python backend
+    from google.protobuf.internal.containers import RepeatedCompositeFieldContainer as RepeatedContainer
 
 from ...proto.jina_pb2 import DocumentProto
 
@@ -16,10 +22,10 @@ __all__ = ['DocumentSet']
 class DocumentSet(MutableSequence):
     """:class:`DocumentSet` is a mutable sequence of :class:`Document`,
     it gives an efficient view of a list of Document. One can iterate over it like
-    a generator but ALSO modify it, count it, get item.
+    a generator but ALSO modify it, count it, get item, or union two 'DocumentSet's using the '+' and '+=' operators.
     """
 
-    def __init__(self, docs_proto: Union['RepeatedCompositeContainer', Sequence['Document']]):
+    def __init__(self, docs_proto: Union['RepeatedContainer', Sequence['Document']]):
         super().__init__()
         self._docs_proto = docs_proto
         self._docs_map = {}
@@ -63,6 +69,19 @@ class DocumentSet(MutableSequence):
         else:
             raise IndexError(f'do not support this index {item}')
 
+    def __add__(self, other: 'DocumentSet'):
+        v = DocumentSet([])
+        for doc in self:
+            v.add(doc)
+        for doc in other:
+            v.add(doc)
+        return v
+
+    def __iadd__(self, other: 'DocumentSet'):
+        for doc in other:
+            self.add(doc)
+        return self
+
     def append(self, doc: 'Document') -> 'Document':
         return self._docs_proto.append(doc.as_pb_object)
 
@@ -78,7 +97,7 @@ class DocumentSet(MutableSequence):
 
     def reverse(self):
         """In-place reverse the sequence """
-        if isinstance(self._docs_proto, RepeatedCompositeContainer):
+        if isinstance(self._docs_proto, RepeatedContainer):
             size = len(self._docs_proto)
             hi_idx = size - 1
             for i in range(int(size / 2)):
